Glossary
--------

encode:
   To represent one set of values using another set of values, by
   constructing a mapping between them.

abstract parameter:
   A set of parameters that act together as a single parameter.

.. dragndrop:: glossary12
    :feedback: Try again!
    :match_1: encode|||To represent one set of values using another set of values, by constructing a mapping between them
    :match_2: abstract parameter|||A set of parameters that act together as a single parameter.

    Match the vocabulary word with its definition.
